==> customer-link-project-api-1.1.5-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app93842/dto/UserInfoDto.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app93842.dto;

/**
 * 用户信息dto
 *
 * @author songp
 * @date 2025/1/10 3:53 下午
 */
public class UserInfoDto {

    /**
     * unionid, 寿险统一的unionid
     */
    private String unionid;

    /**
     * miniOpenid, 小程序的miniOpenid
     */
    private String miniOpenid;

    /**
     * phone, 手机号
     */
    private String phone;

    /**
     * customId, 登录情况下有客户ID
     */
    private String customId;

    /**
     * officerOrEmp, 1业务员，2内勤，3都不是
     */
    private String officerOrEmp;

    /**
     * subscribeFlg, 关注官微服务号状态 true 关注，false 未关注
     */
    private Boolean subscribeFlg;

    /**
     * programLogin, 小程序登录状态 登录/未登录/退出登录
     */
    private String programLogin;

    /**
     * userLevel, 用户认证级别 未认证/手机号认证/实名认证/人脸认证
     */
    private String userLevel;

    /**
     * age, 用户年龄
     */
    private String age;

    /**
     * sex, 用户性别 M - 男 ， F - 女 ， N - 未知
     */
    private String sex;

    /**
     * province, 地域 省份
     */
    private String province;

    /**
     * memberAttribution, 会员归属 未知、个、银、团
     */
    private String memberAttribution;

    /**
     * customLevel, 会员级别 "0:游客,1:大众会员,2:普通会员,3:阳光会员,4:白银会员,5:黄金会员,6:铂金会员,7:钻石会员"
     */
    private String customLevel;

    /**
     * empNp, 服务业务员工号
     */
    private String empNp;

    /**
     * empNO, 用户工号
     */
    private String empNO;

    /**
     * nickname, 昵称
     */
    private String nickname;

    /**
     * headImg, 头像
     */
    private String headImg;

    public String getUnionid() {
        return unionid;
    }

    public void setUnionid(String unionid) {
        this.unionid = unionid;
    }

    public String getMiniOpenid() {
        return miniOpenid;
    }

    public void setMiniOpenid(String miniOpenid) {
        this.miniOpenid = miniOpenid;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getCustomId() {
        return customId;
    }

    public void setCustomId(String customId) {
        this.customId = customId;
    }

    public String getOfficerOrEmp() {
        return officerOrEmp;
    }

    public void setOfficerOrEmp(String officerOrEmp) {
        this.officerOrEmp = officerOrEmp;
    }

    public Boolean getSubscribeFlg() {
        return subscribeFlg;
    }

    public void setSubscribeFlg(Boolean subscribeFlg) {
        this.subscribeFlg = subscribeFlg;
    }

    public String getProgramLogin() {
        return programLogin;
    }

    public void setProgramLogin(String programLogin) {
        this.programLogin = programLogin;
    }

    public String getUserLevel() {
        return userLevel;
    }

    public void setUserLevel(String userLevel) {
        this.userLevel = userLevel;
    }

    public String getAge() {
        return age;
    }

    public void setAge(String age) {
        this.age = age;
    }

    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getMemberAttribution() {
        return memberAttribution;
    }

    public void setMemberAttribution(String memberAttribution) {
        this.memberAttribution = memberAttribution;
    }

    public String getCustomLevel() {
        return customLevel;
    }

    public void setCustomLevel(String customLevel) {
        this.customLevel = customLevel;
    }

    public String getEmpNp() {
        return empNp;
    }

    public void setEmpNp(String empNp) {
        this.empNp = empNp;
    }

    public String getEmpNO() {
        return empNO;
    }

    public void setEmpNO(String empNO) {
        this.empNO = empNO;
    }

    public String getNickname() {
        return nickname;
    }

    public void setNickname(String nickname) {
        this.nickname = nickname;
    }

    public String getHeadImg() {
        return headImg;
    }

    public void setHeadImg(String headImg) {
        this.headImg = headImg;
    }
}

==> customer-link-project-api-1.1.53-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app93842/dto/UserInfoDto.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app93842.dto;

/**
 * 用户信息dto
 *
 * @author songp
 * @date 2025/1/10 3:53 下午
 */
public class UserInfoDto {

    /**
     * unionid, 寿险统一的unionid
     */
    private String unionid;

    /**
     * miniOpenid, 小程序的miniOpenid
     */
    private String miniOpenid;

    /**
     * phone, 手机号
     */
    private String phone;

    /**
     * customId, 登录情况下有客户ID
     */
    private String customId;

    /**
     * officerOrEmp, 1业务员，2内勤，3都不是
     */
    private String officerOrEmp;

    /**
     * subscribeFlg, 关注官微服务号状态 true 关注，false 未关注
     */
    private Boolean subscribeFlg;

    /**
     * programLogin, 小程序登录状态 登录/未登录/退出登录
     */
    private String programLogin;

    /**
     * userLevel, 用户认证级别 未认证/手机号认证/实名认证/人脸认证
     */
    private String userLevel;

    /**
     * age, 用户年龄
     */
    private String age;

    /**
     * sex, 用户性别 M - 男 ， F - 女 ， N - 未知
     */
    private String sex;

    /**
     * province, 地域 省份
     */
    private String province;

    /**
     * memberAttribution, 会员归属 未知、个、银、团
     */
    private String memberAttribution;

    /**
     * customLevel, 会员级别 "0:游客,1:大众会员,2:普通会员,3:阳光会员,4:白银会员,5:黄金会员,6:铂金会员,7:钻石会员"
     */
    private String customLevel;

    /**
     * empNp, 服务业务员工号
     */
    private String empNp;

    /**
     * empNO, 用户工号
     */
    private String empNO;

    /**
     * nickname, 昵称
     */
    private String nickname;

    /**
     * headImg, 头像
     */
    private String headImg;

    /**
     * 是否完成兴趣收集,true 已完成，false 未完成
     */
    private Boolean interestCollection;

    public Boolean getInterestCollection() {
        return interestCollection;
    }

    public void setInterestCollection(Boolean interestCollection) {
        this.interestCollection = interestCollection;
    }

    public String getUnionid() {
        return unionid;
    }

    public void setUnionid(String unionid) {
        this.unionid = unionid;
    }

    public String getMiniOpenid() {
        return miniOpenid;
    }

    public void setMiniOpenid(String miniOpenid) {
        this.miniOpenid = miniOpenid;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getCustomId() {
        return customId;
    }

    public void setCustomId(String customId) {
        this.customId = customId;
    }

    public String getOfficerOrEmp() {
        return officerOrEmp;
    }

    public void setOfficerOrEmp(String officerOrEmp) {
        this.officerOrEmp = officerOrEmp;
    }

    public Boolean getSubscribeFlg() {
        return subscribeFlg;
    }

    public void setSubscribeFlg(Boolean subscribeFlg) {
        this.subscribeFlg = subscribeFlg;
    }

    public String getProgramLogin() {
        return programLogin;
    }

    public void setProgramLogin(String programLogin) {
        this.programLogin = programLogin;
    }

    public String getUserLevel() {
        return userLevel;
    }

    public void setUserLevel(String userLevel) {
        this.userLevel = userLevel;
    }

    public String getAge() {
        return age;
    }

    public void setAge(String age) {
        this.age = age;
    }

    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getMemberAttribution() {
        return memberAttribution;
    }

    public void setMemberAttribution(String memberAttribution) {
        this.memberAttribution = memberAttribution;
    }

    public String getCustomLevel() {
        return customLevel;
    }

    public void setCustomLevel(String customLevel) {
        this.customLevel = customLevel;
    }

    public String getEmpNp() {
        return empNp;
    }

    public void setEmpNp(String empNp) {
        this.empNp = empNp;
    }

    public String getEmpNO() {
        return empNO;
    }

    public void setEmpNO(String empNO) {
        this.empNO = empNO;
    }

    public String getNickname() {
        return nickname;
    }

    public void setNickname(String nickname) {
        this.nickname = nickname;
    }

    public String getHeadImg() {
        return headImg;
    }

    public void setHeadImg(String headImg) {
        this.headImg = headImg;
    }
}
